pub struct AgreementsClient { /* private fields */ }Expand description
Client for agreements operations.
Implementations
Sourceimpl AgreementsClient
impl AgreementsClient
pub fn new(client: Client) -> Self
Sourcepub async fn get_latest_unaccepted_agreement(
&self,
query: Option<GetLatestUnacceptedAgreementQuery>,
) -> Result<GetLatestUnacceptedAgreementResponse, Error>
pub async fn get_latest_unaccepted_agreement( &self, query: Option<GetLatestUnacceptedAgreementQuery>, ) -> Result<GetLatestUnacceptedAgreementResponse, Error>
Get the latest unaccepted agreement for a specific agreement type
Sourcepub async fn record_agreement_acceptance(
&self,
agreement_id: String,
) -> Result<RecordAgreementAcceptanceResponse, Error>
pub async fn record_agreement_acceptance( &self, agreement_id: String, ) -> Result<RecordAgreementAcceptanceResponse, Error>
Record the acceptance of a specific agreement by its ID