pub struct AllocationsClient { /* private fields */ }Expand description
Client for allocations operations.
Implementations
Sourceimpl AllocationsClient
impl AllocationsClient
pub fn new(client: Client) -> Self
Sourcepub async fn list_allocations(
&self,
query: Option<ListAllocationsQuery>,
) -> Result<ListAllocationsResponse, Error>
pub async fn list_allocations( &self, query: Option<ListAllocationsQuery>, ) -> Result<ListAllocationsResponse, Error>
Lists the allocations of your organization.
Sourcepub async fn create_allocation(
&self,
body: CreateAllocationRequest,
) -> Result<CreateAllocationResponse, Error>
pub async fn create_allocation( &self, body: CreateAllocationRequest, ) -> Result<CreateAllocationResponse, Error>
Create a new allocation.
An allocation deposits assets from one of your wallets into a rewards-earning protocol. Two providers are available:
Sourcepub async fn list_allocation_actions(
&self,
allocation_id: String,
query: Option<ListAllocationActionsQuery>,
) -> Result<ListAllocationActionsResponse, Error>
pub async fn list_allocation_actions( &self, allocation_id: String, query: Option<ListAllocationActionsQuery>, ) -> Result<ListAllocationActionsResponse, Error>
Retrieve the list of actions for a specific allocation.
Sourcepub async fn create_allocation_action(
&self,
allocation_id: String,
body: CreateAllocationActionRequest,
) -> Result<CreateAllocationActionResponse, Error>
pub async fn create_allocation_action( &self, allocation_id: String, body: CreateAllocationActionRequest, ) -> Result<CreateAllocationActionResponse, Error>
Create a new action for an existing allocation.
Sourcepub async fn get_allocation(
&self,
allocation_id: String,
) -> Result<GetAllocationResponse, Error>
pub async fn get_allocation( &self, allocation_id: String, ) -> Result<GetAllocationResponse, Error>
Retrieve the details of a specific allocation.
Sourcepub async fn get_allocations_info(
&self,
) -> Result<GetAllocationsInfoResponse, Error>
pub async fn get_allocations_info( &self, ) -> Result<GetAllocationsInfoResponse, Error>
Retrieve the current reward rate (APY) for each supported allocation protocol.