pub struct ExchangesClient { /* private fields */ }Expand description
Client for exchanges operations.
Implementations
Sourceimpl ExchangesClient
impl ExchangesClient
pub fn new(client: Client) -> Self
Sourcepub async fn get_exchange(
&self,
exchange_id: String,
) -> Result<GetExchangeResponse, Error>
pub async fn get_exchange( &self, exchange_id: String, ) -> Result<GetExchangeResponse, Error>
Retrieve the details of a specific exchange integration configuration.
Sourcepub async fn delete_exchange(
&self,
exchange_id: String,
) -> Result<DeleteExchangeResponse, Error>
pub async fn delete_exchange( &self, exchange_id: String, ) -> Result<DeleteExchangeResponse, Error>
Delete the exchange configuration from your organization.
Sourcepub async fn list_exchanges(
&self,
query: Option<ListExchangesQuery>,
) -> Result<ListExchangesResponse, Error>
pub async fn list_exchanges( &self, query: Option<ListExchangesQuery>, ) -> Result<ListExchangesResponse, Error>
List all configured exchange integrations.
Sourcepub async fn create_exchange(
&self,
body: CreateExchangeRequest,
) -> Result<CreateExchangeResponse, Error>
pub async fn create_exchange( &self, body: CreateExchangeRequest, ) -> Result<CreateExchangeResponse, Error>
Link your organization with a cryptocurrency exchange.
Sourcepub async fn list_accounts(
&self,
exchange_id: String,
query: Option<ListAccountsQuery>,
) -> Result<ListAccountsResponse, Error>
pub async fn list_accounts( &self, exchange_id: String, query: Option<ListAccountsQuery>, ) -> Result<ListAccountsResponse, Error>
Get a list of accounts for a specific exchange.
Sourcepub async fn list_account_assets(
&self,
exchange_id: String,
account_id: String,
query: Option<ListAccountAssetsQuery>,
) -> Result<ListAccountAssetsResponse, Error>
pub async fn list_account_assets( &self, exchange_id: String, account_id: String, query: Option<ListAccountAssetsQuery>, ) -> Result<ListAccountAssetsResponse, Error>
Retrieve the list of assets for a specific account on a specific exchange.
Sourcepub async fn list_asset_withdrawal_networks(
&self,
exchange_id: String,
account_id: String,
asset: String,
) -> Result<Value, Error>
pub async fn list_asset_withdrawal_networks( &self, exchange_id: String, account_id: String, asset: String, ) -> Result<Value, Error>
Lists the networks to which the given asset can be withdrawn from an exchange account.
Sourcepub async fn create_exchange_deposit(
&self,
exchange_id: String,
account_id: String,
body: CreateExchangeDepositRequest,
) -> Result<CreateExchangeDepositResponse, Error>
pub async fn create_exchange_deposit( &self, exchange_id: String, account_id: String, body: CreateExchangeDepositRequest, ) -> Result<CreateExchangeDepositResponse, Error>
Creates a new exchange deposit transaction.
Sourcepub async fn create_exchange_withdrawal(
&self,
exchange_id: String,
account_id: String,
body: CreateExchangeWithdrawalRequest,
) -> Result<CreateExchangeWithdrawalResponse, Error>
pub async fn create_exchange_withdrawal( &self, exchange_id: String, account_id: String, body: CreateExchangeWithdrawalRequest, ) -> Result<CreateExchangeWithdrawalResponse, Error>
Creates a new exchange withdrawal transaction.