pub struct PayoutsClient { /* private fields */ }Expand description
Client for payouts operations.
Implementations
Sourceimpl PayoutsClient
impl PayoutsClient
pub fn new(client: Client) -> Self
Sourcepub async fn list_payouts(
&self,
query: Option<ListPayoutsQuery>,
) -> Result<ListPayoutsResponse, Error>
pub async fn list_payouts( &self, query: Option<ListPayoutsQuery>, ) -> Result<ListPayoutsResponse, Error>
List payouts with optional filtering and pagination.
Sourcepub async fn create_payout(
&self,
body: CreatePayoutRequest,
) -> Result<Value, Error>
pub async fn create_payout( &self, body: CreatePayoutRequest, ) -> Result<Value, Error>
Create a new payout to convert crypto assets to fiat currency.
Sourcepub async fn request_payout_quote(
&self,
body: RequestPayoutQuoteRequest,
) -> Result<RequestPayoutQuoteResponse, Error>
pub async fn request_payout_quote( &self, body: RequestPayoutQuoteRequest, ) -> Result<RequestPayoutQuoteResponse, Error>
Request a quote from a given provider for a payout. Returns estimated fiat amount and fees.
Sourcepub async fn get_payout_status(&self, payout_id: String) -> Result<Value, Error>
pub async fn get_payout_status(&self, payout_id: String) -> Result<Value, Error>
Retrieve the current status of a payout by its ID.
Sourcepub async fn create_payout_action(
&self,
payout_id: String,
body: CreatePayoutActionRequest,
) -> Result<CreatePayoutActionResponse, Error>
pub async fn create_payout_action( &self, payout_id: String, body: CreatePayoutActionRequest, ) -> Result<CreatePayoutActionResponse, Error>
Perform an action on a payout, such as confirming or canceling.