SignersClient

Struct SignersClient 

pub struct SignersClient { /* private fields */ }
Client for signers operations.

Implementations

Source

impl SignersClient

pub fn new(client: Client) -> Self

pub async fn cancel_fleet_operation( &self, store_id: String, body: CancelFleetOperationRequest, ) -> Result<CancelFleetOperationResponse, Error>

Cancel Fleet Operation

pub async fn create_add_mac_user_input( &self, store_id: String, body: CreateAddMacUserInputRequest, ) -> Result<(), Error>

Creates the input archive for an add-mac-user fleet operation, which registers a new Mac operator machine with an HSM in the key store’s trust set.

pub async fn create_add_provisioner_input( &self, store_id: String, body: CreateAddProvisionerInputRequest, ) -> Result<(), Error>

Creates the input archive for an add-provisioner fleet operation, which registers a new provisioner YubiKey into the key store’s governance set.

pub async fn create_clone_input( &self, store_id: String, body: CreateCloneInputRequest, ) -> Result<(), Error>

Creates the input archive for a clone fleet operation, which replicates a key store from a source HSM to a target HSM.

pub async fn create_genesis_input( &self, store_id: String, body: CreateGenesisInputRequest, ) -> Result<(), Error>

Creates the input archive for a genesis fleet operation, which provisions a new offline signer fleet and generates the key store’s initial signing keys.

pub async fn create_key_harvest_input( &self, store_id: String, body: CreateKeyHarvestInputRequest, ) -> Result<(), Error>

Create Key Harvest Input

pub async fn create_onchain_sign_input( &self, store_id: String, body: CreateOnchainSignInputRequest, ) -> Result<(), Error>

Creates the input archive for an onchain-sign operation covering the key store’s pending signature requests.

pub async fn create_proof_of_control_input( &self, store_id: String, body: CreateProofOfControlInputRequest, ) -> Result<(), Error>

Creates the input archive for a proof-of-control operation covering the keys of the specified wallets.

pub async fn list_key_stores(&self) -> Result<ListKeyStoresResponse, Error>

Lists the key stores of your organization.

pub async fn list_signers(&self) -> Result<ListSignersResponse, Error>

Lists the signer clusters of your key store, including each signer’s ID and encryption public key.

pub async fn submit_add_mac_user_output( &self, store_id: String, body: SubmitAddMacUserOutputRequest, file: MultipartFile, ) -> Result<SubmitAddMacUserOutputResponse, Error>

Submits the output archive produced by the offline signer fleet for an add-mac-user operation.

pub async fn submit_add_provisioner_output( &self, store_id: String, body: SubmitAddProvisionerOutputRequest, file: MultipartFile, ) -> Result<SubmitAddProvisionerOutputResponse, Error>

Submits the output archive produced by the offline signer fleet for an add-provisioner operation.

pub async fn submit_clone_output( &self, store_id: String, body: SubmitCloneOutputRequest, file: MultipartFile, ) -> Result<SubmitCloneOutputResponse, Error>

Submits the output archive produced by the offline signer fleet for a clone operation.

pub async fn submit_genesis_output( &self, store_id: String, body: SubmitGenesisOutputRequest, file: MultipartFile, ) -> Result<SubmitGenesisOutputResponse, Error>

Submits the output archive produced by the offline signer fleet for a genesis operation.

pub async fn submit_key_harvest_output( &self, store_id: String, body: SubmitKeyHarvestOutputRequest, file: MultipartFile, ) -> Result<SubmitKeyHarvestOutputResponse, Error>

Submit Key Harvest Output

pub async fn submit_onchain_sign_output( &self, store_id: String, body: SubmitOnchainSignOutputRequest, file: MultipartFile, ) -> Result<SubmitOnchainSignOutputResponse, Error>

Submits the output archive produced by the offline signer fleet for an onchain-sign operation.

pub async fn submit_proof_of_control_output( &self, store_id: String, body: SubmitProofOfControlOutputRequest, file: MultipartFile, ) -> Result<SubmitProofOfControlOutputResponse, Error>

Submits the output archive produced by the offline signer fleet for a proof-of-control operation.