pub struct SwapsClient { /* private fields */ }Expand description
Client for swaps operations.
Implementations
Sourceimpl SwapsClient
impl SwapsClient
pub fn new(client: Client) -> Self
Sourcepub async fn list_swaps(
&self,
query: Option<ListSwapsQuery>,
) -> Result<ListSwapsResponse, Error>
pub async fn list_swaps( &self, query: Option<ListSwapsQuery>, ) -> Result<ListSwapsResponse, Error>
List all swaps with pagination
Sourcepub async fn create_swap(
&self,
body: CreateSwapRequest,
) -> Result<CreateSwapResponse, Error>
pub async fn create_swap( &self, body: CreateSwapRequest, ) -> Result<CreateSwapResponse, Error>
Create a new swap based on an existing quote. This is the second step of the Swap flow.
Sourcepub async fn request_swap_quote(
&self,
body: RequestSwapQuoteRequest,
) -> Result<RequestSwapQuoteResponse, Error>
pub async fn request_swap_quote( &self, body: RequestSwapQuoteRequest, ) -> Result<RequestSwapQuoteResponse, Error>
Request a quote from a given provider for swapping assets. This is the first step of the Swap flow.
Sourcepub async fn get_swap(&self, swap_id: String) -> Result<GetSwapResponse, Error>
pub async fn get_swap(&self, swap_id: String) -> Result<GetSwapResponse, Error>
Get details of a specific swap by its ID
Sourcepub async fn get_swap_quote(
&self,
quote_id: String,
) -> Result<GetSwapQuoteResponse, Error>
pub async fn get_swap_quote( &self, quote_id: String, ) -> Result<GetSwapQuoteResponse, Error>
Get details of a specific swap quote by its ID