DelegatedWalletsClient

Struct DelegatedWalletsClient 

pub struct DelegatedWalletsClient { /* private fields */ }
Delegated client for wallets operations. Signed operations are split into init/complete pairs so the challenge can be signed on the user side.

Implementations

Source

impl DelegatedWalletsClient

pub fn new(client: Client) -> Self

pub async fn abort_transaction_init( &self, wallet_id: String, transaction_id: String, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for abortTransaction: returns the challenge to sign. Pass the signed assertion to abort_transaction_complete with the same arguments.

pub async fn abort_transaction_complete( &self, wallet_id: String, transaction_id: String, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<AbortTransactionResponse, Error>

Finishes delegated signing for abortTransaction: submits the signed challenge and issues the request.

pub async fn abort_transfer_init( &self, wallet_id: String, transfer_id: String, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for abortTransfer: returns the challenge to sign. Pass the signed assertion to abort_transfer_complete with the same arguments.

pub async fn abort_transfer_complete( &self, wallet_id: String, transfer_id: String, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<AbortTransferResponse, Error>

Finishes delegated signing for abortTransfer: submits the signed challenge and issues the request.

pub async fn activate_wallet_init( &self, wallet_id: String, body: ActivateWalletRequest, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for activateWallet: returns the challenge to sign. Pass the signed assertion to activate_wallet_complete with the same arguments.

pub async fn activate_wallet_complete( &self, wallet_id: String, body: ActivateWalletRequest, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<ActivateWalletResponse, Error>

Finishes delegated signing for activateWallet: submits the signed challenge and issues the request.

pub async fn list_transactions( &self, wallet_id: String, query: Option<ListTransactionsQuery>, ) -> Result<ListTransactionsResponse, Error>

Retrieves a list of transactions requests for the specified wallet.

pub async fn sign_and_broadcast_transaction_init( &self, wallet_id: String, body: SignAndBroadcastTransactionRequest, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for signAndBroadcastTransaction: returns the challenge to sign. Pass the signed assertion to sign_and_broadcast_transaction_complete with the same arguments.

pub async fn sign_and_broadcast_transaction_complete( &self, wallet_id: String, body: SignAndBroadcastTransactionRequest, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<SignAndBroadcastTransactionResponse, Error>

Finishes delegated signing for signAndBroadcastTransaction: submits the signed challenge and issues the request.

pub async fn cancel_transaction_init( &self, wallet_id: String, transaction_id: String, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for cancelTransaction: returns the challenge to sign. Pass the signed assertion to cancel_transaction_complete with the same arguments.

pub async fn cancel_transaction_complete( &self, wallet_id: String, transaction_id: String, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<CancelTransactionResponse, Error>

Finishes delegated signing for cancelTransaction: submits the signed challenge and issues the request.

pub async fn cancel_transfer_init( &self, wallet_id: String, transfer_id: String, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for cancelTransfer: returns the challenge to sign. Pass the signed assertion to cancel_transfer_complete with the same arguments.

pub async fn cancel_transfer_complete( &self, wallet_id: String, transfer_id: String, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<CancelTransferResponse, Error>

Finishes delegated signing for cancelTransfer: submits the signed challenge and issues the request.

pub async fn proxy_arequest_to_the_canton_ledger_api( &self, wallet_id: String, body: ProxyARequestToTheCantonLedgerApiRequest, ) -> Result<Value, Error>

Proxies a request to the Canton Ledger API associated with this wallet, using the validator’s OAuth2 credentials. Restricted to a curated allow-list of read-style resources. Used to satisfy the Canton WalletConnect canton_ledgerApi method.

pub async fn speed_up_transaction_init( &self, wallet_id: String, transaction_id: String, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for speedUpTransaction: returns the challenge to sign. Pass the signed assertion to speed_up_transaction_complete with the same arguments.

pub async fn speed_up_transaction_complete( &self, wallet_id: String, transaction_id: String, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<SpeedUpTransactionResponse, Error>

Finishes delegated signing for speedUpTransaction: submits the signed challenge and issues the request.

pub async fn speed_up_transfer_init( &self, wallet_id: String, transfer_id: String, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for speedUpTransfer: returns the challenge to sign. Pass the signed assertion to speed_up_transfer_complete with the same arguments.

pub async fn speed_up_transfer_complete( &self, wallet_id: String, transfer_id: String, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<SpeedUpTransferResponse, Error>

Finishes delegated signing for speedUpTransfer: submits the signed challenge and issues the request.

pub async fn list_wallets( &self, query: Option<ListWalletsQuery>, ) -> Result<ListWalletsResponse, Error>

Retrieves the list of Wallets in your organization. You can filter the results by owner (either by owner id or owner username). Pagination is supported via limit and paginationToken parameters.

pub async fn create_wallet_init( &self, body: CreateWalletRequest, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for createWallet: returns the challenge to sign. Pass the signed assertion to create_wallet_complete with the same arguments.

pub async fn create_wallet_complete( &self, body: CreateWalletRequest, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<CreateWalletResponse, Error>

Finishes delegated signing for createWallet: submits the signed challenge and issues the request.

pub async fn get_transaction( &self, wallet_id: String, transaction_id: String, ) -> Result<GetTransactionResponse, Error>

Retrieve information about a specific transaction.

pub async fn get_transfer( &self, wallet_id: String, transfer_id: String, ) -> Result<GetTransferResponse, Error>

Retrieves a Wallet Transfer Request by its ID.

pub async fn get_wallet( &self, wallet_id: String, ) -> Result<GetWalletResponse, Error>

Retrieves a Wallet information by its ID.

pub async fn update_wallet_init( &self, wallet_id: String, body: UpdateWalletRequest, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for updateWallet: returns the challenge to sign. Pass the signed assertion to update_wallet_complete with the same arguments.

pub async fn update_wallet_complete( &self, wallet_id: String, body: UpdateWalletRequest, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<UpdateWalletResponse, Error>

Finishes delegated signing for updateWallet: submits the signed challenge and issues the request.

pub async fn get_wallet_assets( &self, wallet_id: String, query: Option<GetWalletAssetsQuery>, ) -> Result<GetWalletAssetsResponse, Error>

Retrieves a list of assets owned by the specified wallet. Return values vary by chain as shown below.

pub async fn get_wallet_history( &self, wallet_id: String, query: Option<GetWalletHistoryQuery>, ) -> Result<GetWalletHistoryResponse, Error>

Retrieves a list of historical on chain activities for the specified wallet.

The list reflects the indexed on-chain activity: it includes confirmed transactions only.

pub async fn get_wallet_nfts( &self, wallet_id: String, ) -> Result<GetWalletNftsResponse, Error>

Retrieves a list of NFTs owned by the specified Wallet.

pub async fn import_wallet_init( &self, body: ImportWalletRequest, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for importWallet: returns the challenge to sign. Pass the signed assertion to import_wallet_complete with the same arguments.

pub async fn import_wallet_complete( &self, body: ImportWalletRequest, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<ImportWalletResponse, Error>

Finishes delegated signing for importWallet: submits the signed challenge and issues the request.

pub async fn list_transfers( &self, wallet_id: String, query: Option<ListTransfersQuery>, ) -> Result<ListTransfersResponse, Error>

Retrieves a list of transfer requests for the specified wallet.

pub async fn transfer_asset_init( &self, wallet_id: String, body: TransferAssetRequest, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for transferAsset: returns the challenge to sign. Pass the signed assertion to transfer_asset_complete with the same arguments.

pub async fn transfer_asset_complete( &self, wallet_id: String, body: TransferAssetRequest, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<TransferAssetResponse, Error>

Finishes delegated signing for transferAsset: submits the signed challenge and issues the request.

pub async fn tag_wallet_init( &self, wallet_id: String, body: TagWalletRequest, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for tagWallet: returns the challenge to sign. Pass the signed assertion to tag_wallet_complete with the same arguments.

pub async fn tag_wallet_complete( &self, wallet_id: String, body: TagWalletRequest, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<TagWalletResponse, Error>

Finishes delegated signing for tagWallet: submits the signed challenge and issues the request.

pub async fn untag_wallet_init( &self, wallet_id: String, body: UntagWalletRequest, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for untagWallet: returns the challenge to sign. Pass the signed assertion to untag_wallet_complete with the same arguments.

pub async fn untag_wallet_complete( &self, wallet_id: String, body: UntagWalletRequest, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<UntagWalletResponse, Error>

Finishes delegated signing for untagWallet: submits the signed challenge and issues the request.

pub async fn get_offer( &self, wallet_id: String, offer_id: String, ) -> Result<GetOfferResponse, Error>

Retrieve information about a specific offer received on your wallet.

pub async fn list_offers( &self, wallet_id: String, query: Option<ListOffersQuery>, ) -> Result<ListOffersResponse, Error>

List all offers received on a specific wallet.

pub async fn accept_offer_init( &self, wallet_id: String, offer_id: String, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for acceptOffer: returns the challenge to sign. Pass the signed assertion to accept_offer_complete with the same arguments.

pub async fn accept_offer_complete( &self, wallet_id: String, offer_id: String, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<AcceptOfferResponse, Error>

Finishes delegated signing for acceptOffer: submits the signed challenge and issues the request.

pub async fn reject_offer_init( &self, wallet_id: String, offer_id: String, ) -> Result<UserActionChallenge, Error>

Starts delegated signing for rejectOffer: returns the challenge to sign. Pass the signed assertion to reject_offer_complete with the same arguments.

pub async fn reject_offer_complete( &self, wallet_id: String, offer_id: String, challenge_identifier: String, assertion: CredentialAssertion, ) -> Result<RejectOfferResponse, Error>

Finishes delegated signing for rejectOffer: submits the signed challenge and issues the request.

pub async fn list_org_wallet_history( &self, query: Option<ListOrgWalletHistoryQuery>, ) -> Result<Value, Error>

Retrieve the transaction history across all wallets within a specified timeframe. The time range is unbounded, but the CSV export is capped at 100,000 rows.