WalletsClient

Struct WalletsClient 

pub struct WalletsClient { /* private fields */ }
Client for wallets operations.

Implementations

Source

impl WalletsClient

pub fn new(client: Client) -> Self

pub async fn abort_transaction( &self, wallet_id: String, transaction_id: String, ) -> Result<AbortTransactionResponse, Error>

Aborts a transaction that is currently in ‘Executing’ status and has not yet been signed. Sets the transaction status to ‘Failed’ and removes it from the retry queue.

This is useful when a transaction is stuck in the execution pipeline (e.g., during construct or sign phase) and you want to abort it without waiting for it to fail on its own.

pub async fn abort_transfer( &self, wallet_id: String, transfer_id: String, ) -> Result<AbortTransferResponse, Error>

Aborts a transfer that is currently in ‘Executing’ status and has not yet been signed. Sets the transfer status to ‘Failed’ and removes it from the retry queue.

This is useful when a transfer is stuck in the execution pipeline (e.g., during construct or sign phase) and you want to abort it without waiting for it to fail on its own.

pub async fn activate_wallet( &self, wallet_id: String, body: ActivateWalletRequest, ) -> Result<ActivateWalletResponse, Error>

Activates a wallet by deploying the account contract on-chain, making it ready for transactions.

This operation is required for wallets on networks where you need to explicitly activate your account on-chain
before it can be used for transactions.
pub async fn list_transactions( &self, wallet_id: String, query: Option<ListTransactionsQuery>, ) -> Result<ListTransactionsResponse, Error>

Retrieves a list of transactions requests for the specified wallet.

pub async fn sign_and_broadcast_transaction( &self, wallet_id: String, body: SignAndBroadcastTransactionRequest, ) -> Result<SignAndBroadcastTransactionResponse, Error>

Sign & Broadcast transaction enables communication with any arbitrary smart contract of the target blockchain. You can construct a transaction that performs a complex task and this endpoint will sign the transaction, add the signature and broadcast it to chain. It can be used to call smart contract functions like mint tokens and even deploy new smart contracts.

StatusDefinition
pub async fn cancel_transaction( &self, wallet_id: String, transaction_id: String, ) -> Result<CancelTransactionResponse, Error>

Cancels an EVM transaction by creating a replacement transaction with the same nonce. The new transaction sends 0 value to the same address, effectively nullifying the original transaction.

This endpoint works for:

  • EVM-compatible networks (Ethereum, Polygon, BSC, etc.)
pub async fn cancel_transfer( &self, wallet_id: String, transfer_id: String, ) -> Result<CancelTransferResponse, Error>

Cancels an EVM transfer by creating a replacement transaction with the same nonce. The new transaction sends 0 value to the same address, effectively nullifying the original transfer.

This endpoint works for:

  • EVM-compatible networks (Ethereum, Polygon, BSC, etc.)
pub async fn proxy_arequest_to_the_canton_ledger_api( &self, wallet_id: String, body: ProxyARequestToTheCantonLedgerApiRequest, ) -> Result<Value, Error>

Proxies a request to the Canton Ledger API associated with this wallet, using the validator’s OAuth2 credentials. Restricted to a curated allow-list of read-style resources. Used to satisfy the Canton WalletConnect canton_ledgerApi method.

pub async fn speed_up_transaction( &self, wallet_id: String, transaction_id: String, ) -> Result<SpeedUpTransactionResponse, Error>

Speeds up a transaction by creating a replacement transaction with the same parameters but higher gas fees.

This endpoint only works for:

  • EVM-compatible networks (Ethereum, Polygon, BSC, etc.)
pub async fn speed_up_transfer( &self, wallet_id: String, transfer_id: String, ) -> Result<SpeedUpTransferResponse, Error>

Speeds up a transfer by creating a replacement transaction with the same parameters but higher gas fees.

This endpoint only works for:

  • EVM-compatible networks (Ethereum, Polygon, BSC, etc.)
pub async fn list_wallets( &self, query: Option<ListWalletsQuery>, ) -> Result<ListWalletsResponse, Error>

Retrieves the list of Wallets in your organization. You can filter the results by owner (either by owner id or owner username). Pagination is supported via limit and paginationToken parameters.

pub async fn create_wallet( &self, body: CreateWalletRequest, ) -> Result<CreateWalletResponse, Error>

Creates a new Wallet associated with the given chain (such as Bitcoin or Ethereum ). Returns a new wallet entity.

pub async fn get_transaction( &self, wallet_id: String, transaction_id: String, ) -> Result<GetTransactionResponse, Error>

Retrieve information about a specific transaction.

pub async fn get_transfer( &self, wallet_id: String, transfer_id: String, ) -> Result<GetTransferResponse, Error>

Retrieves a Wallet Transfer Request by its ID.

pub async fn get_wallet( &self, wallet_id: String, ) -> Result<GetWalletResponse, Error>

Retrieves a Wallet information by its ID.

pub async fn update_wallet( &self, wallet_id: String, body: UpdateWalletRequest, ) -> Result<UpdateWalletResponse, Error>

Updates the name of an existing wallet.

pub async fn get_wallet_assets( &self, wallet_id: String, query: Option<GetWalletAssetsQuery>, ) -> Result<GetWalletAssetsResponse, Error>

Retrieves a list of assets owned by the specified wallet. Return values vary by chain as shown below.

pub async fn get_wallet_history( &self, wallet_id: String, query: Option<GetWalletHistoryQuery>, ) -> Result<GetWalletHistoryResponse, Error>

Retrieves a list of historical on chain activities for the specified wallet.

The list reflects the indexed on-chain activity: it includes confirmed transactions only.

pub async fn get_wallet_nfts( &self, wallet_id: String, ) -> Result<GetWalletNftsResponse, Error>

Retrieves a list of NFTs owned by the specified Wallet.

pub async fn import_wallet( &self, body: ImportWalletRequest, ) -> Result<ImportWalletResponse, Error>

This endpoint is not enabled by default. [Contact Dfns](https://support.dfns.co) to have it activated.
pub async fn list_transfers( &self, wallet_id: String, query: Option<ListTransfersQuery>, ) -> Result<ListTransfersResponse, Error>

Retrieves a list of transfer requests for the specified wallet.

pub async fn transfer_asset( &self, wallet_id: String, body: TransferAssetRequest, ) -> Result<TransferAssetResponse, Error>

Transfer an asset out of the specified wallet to a destination address. For all fungible token transfers, the transfer amount must be specified in the minimum denomination of that token. For example, use the amount in Satoshi for a Bitcoin transfer, or the amount in Wei for an Ethereum transfer etc.

pub async fn tag_wallet( &self, wallet_id: String, body: TagWalletRequest, ) -> Result<TagWalletResponse, Error>

Add a Tag to a wallet.

pub async fn untag_wallet( &self, wallet_id: String, body: UntagWalletRequest, ) -> Result<UntagWalletResponse, Error>

Removes the specified tags from a wallet.

pub async fn get_offer( &self, wallet_id: String, offer_id: String, ) -> Result<GetOfferResponse, Error>

Retrieve information about a specific offer received on your wallet.

pub async fn list_offers( &self, wallet_id: String, query: Option<ListOffersQuery>, ) -> Result<ListOffersResponse, Error>

List all offers received on a specific wallet.

pub async fn accept_offer( &self, wallet_id: String, offer_id: String, ) -> Result<AcceptOfferResponse, Error>

Accept an offer received on your wallet.

pub async fn reject_offer( &self, wallet_id: String, offer_id: String, ) -> Result<RejectOfferResponse, Error>

Reject an offer received on your wallet.

pub async fn list_org_wallet_history( &self, query: Option<ListOrgWalletHistoryQuery>, ) -> Result<Value, Error>

Retrieve the transaction history across all wallets within a specified timeframe. The time range is unbounded, but the CSV export is capped at 100,000 rows.