WebhooksClient

Struct WebhooksClient 

pub struct WebhooksClient { /* private fields */ }
Client for webhooks operations.

Implementations

Source

impl WebhooksClient

pub fn new(client: Client) -> Self

pub async fn list_webhooks( &self, query: Option<ListWebhooksQuery>, ) -> Result<ListWebhooksResponse, Error>

List all webhooks for the authenticated user’s organization. The results are paginated.

pub async fn create_webhook( &self, body: CreateWebhookRequest, ) -> Result<CreateWebhookResponse, Error>

Register a new webhook.

pub async fn get_webhook( &self, webhook_id: String, ) -> Result<GetWebhookResponse, Error>

Retrieve information about a specific webhook.

pub async fn update_webhook( &self, webhook_id: String, body: UpdateWebhookRequest, ) -> Result<UpdateWebhookResponse, Error>

Update the definition of an existing webhook.

pub async fn delete_webhook( &self, webhook_id: String, ) -> Result<DeleteWebhookResponse, Error>

Deletes an existing webhook registration.

pub async fn ping_webhook( &self, webhook_id: String, ) -> Result<PingWebhookResponse, Error>

This endpoint is meant for webhook setup and troubleshooting. Calling the endpoint will trigger a fake test event that will be pushed to the webhook URL. The fake event will not be saved and not appear in further requests to Webhook Events.

pub async fn get_webhook_event( &self, webhook_id: String, webhook_event_id: String, ) -> Result<GetWebhookEventResponse, Error>

Retrieve a specific webhook event details by its ID.

We only keep a trace of those Webhook Events in our system for a **retention period of 31 days**. Past that, they are discarded, so you cannot see them using [List Webhook Events](https://docs.dfns.co/api-reference/webhooks/list-webhook-events) or [Get Webhook Event](https://docs.dfns.co/api-reference/webhooks/get-webhook-event) endpoints.
pub async fn list_webhook_events( &self, webhook_id: String, query: Option<ListWebhookEventsQuery>, ) -> Result<ListWebhookEventsResponse, Error>

Lists all events for a given webhook.