pub struct NetworksClient { /* private fields */ }Expand description
Client for networks operations.
Implementations
Sourceimpl NetworksClient
impl NetworksClient
pub fn new(client: Client) -> Self
Sourcepub async fn estimate_fees(
&self,
query: Option<EstimateFeesQuery>,
) -> Result<Value, Error>
pub async fn estimate_fees( &self, query: Option<EstimateFeesQuery>, ) -> Result<Value, Error>
Gets real-time fee details for a given network, allowing users to make decisions based on their preferences for transaction speed/priority. Three levels of priority will be displayed: slow, standard, fast.
Sourcepub async fn call_function(
&self,
network: String,
body: CallFunctionRequest,
) -> Result<Value, Error>
pub async fn call_function( &self, network: String, body: CallFunctionRequest, ) -> Result<Value, Error>
Call a read-only function on a smart contract. In Solidity, these are functions with the state mutability set to view.
Sourcepub async fn get_canton_validator(
&self,
network: String,
validator_id: String,
) -> Result<GetCantonValidatorResponse, Error>
pub async fn get_canton_validator( &self, network: String, validator_id: String, ) -> Result<GetCantonValidatorResponse, Error>
Return a configured Canton Validator in your organization.
Sourcepub async fn update_canton_validator(
&self,
network: String,
validator_id: String,
body: UpdateCantonValidatorRequest,
) -> Result<UpdateCantonValidatorResponse, Error>
pub async fn update_canton_validator( &self, network: String, validator_id: String, body: UpdateCantonValidatorRequest, ) -> Result<UpdateCantonValidatorResponse, Error>
Update an existing Canton Validator configuration.
Read details about the process here.
Sourcepub async fn delete_canton_validator(
&self,
network: String,
validator_id: String,
) -> Result<DeleteCantonValidatorResponse, Error>
pub async fn delete_canton_validator( &self, network: String, validator_id: String, ) -> Result<DeleteCantonValidatorResponse, Error>
Delete a specific Canton Validator configuration.
Sourcepub async fn list_canton_validators(
&self,
network: String,
query: Option<ListCantonValidatorsQuery>,
) -> Result<ListCantonValidatorsResponse, Error>
pub async fn list_canton_validators( &self, network: String, query: Option<ListCantonValidatorsQuery>, ) -> Result<ListCantonValidatorsResponse, Error>
Retrieve the list of configured Canton Validators in your organization.
Sourcepub async fn create_canton_validator(
&self,
network: String,
body: CreateCantonValidatorRequest,
) -> Result<CreateCantonValidatorResponse, Error>
pub async fn create_canton_validator( &self, network: String, body: CreateCantonValidatorRequest, ) -> Result<CreateCantonValidatorResponse, Error>
Link a Canton Validator to your organization. This is required in order to create wallets or interact with the Canton network.
The Shared option allows you to use a shared validator hosted by Dfns and get started in seconds, while the Custom option allows you to connect your own validator and ledger nodes using OAuth2 authentication.